@@ -6,7 +6,7 @@ def json(fn=None, indent=None, ensure_ascii=False, mimetype='application/json'):
     def decorator(fn):
         def _fn(request, *args, **kwargs):
             data = fn(request, *args, **kwargs)
-            return render_json(data, indent=indent, ensure_ascii=ensure_ascii, content_type=mimetype)
+            return render_json(data, indent=indent, ensure_ascii=ensure_ascii, mimetype=mimetype)
 
         return _fn
 
